@@ -29,6 +29,9 @@ public:
 
 public slots:
 
+signals:
+	void clicked();
+
 private slots:
 	void selectRegion(QString region);
 	void selectChannel(QString channel);
