@@ -663,7 +663,7 @@ void MainWindow::showRecordMessage()
 		QString sdate = QDate::fromString(_channelDataMap[progKey].sdate, Qt::TextDate).toString("dd/MM");
 		//qDebug() << _channelDataMap[progKey].stime;
 		QString stime = QTime::fromString(_channelDataMap[progKey].stime, "HH:mm:ss").toString("HH:mm");
-		QString recordMsg = _channelDataMap[progKey].title + "." +_channelDataMap[progKey].channelId + "." + sdate + "." + stime;
+		QString recordMsg = _channelDataMap[progKey].title + "." +_channelDataMap[progKey].channelId.replace('_'," ") + "." + sdate + "." + stime;
 
 		QStringList dataToSender;
 		dataToSender << recordMsg << "61759";
